class DashboardController < ApplicationController
  before_filter :require_user
  
  def index
    params.merge!({:minutes_ago => 60})
    respond_to do |format|
      format.html     { render }
      format.iphone   { render }
    end
  end
  
  def daily
    params.merge!({:minutes_ago => 1440})
    render :action => 'index'
  end
  
  def custom
    render :action => 'index'
  end
  
  def threat_indexes
    @threats = Event.threat_indexes params
    # Make sure that we pass the actual time to the events page instead of minutes ago. Passing minutes
    # would be a moving target when what we should really want from this is a point in time snapshot.
    unless params[:minutes_ago].blank?
      params.merge!({:start_date => params[:minutes_ago].to_i.minutes.ago.strftime("%Y-%m-%d %H:%M"), :minutes_ago => ''})
    end
    respond_to do |format|
      format.html   { render :layout => false }
      format.xml    { render :xml => @threats.to_xml(:methods => [ :formatted_source_address ]) }
      format.json   { render :json => @threats.to_json(:methods => [ :formatted_source_address ]) }
      format.iphone { render }
    end
  end
  
  def alert_severities
    @alert_severities = Event.get_alert_severities params
    respond_to do |format|
      format.html   { render :layout => false }
      format.iphone { render }
      format.xml    { render :xml => @alert_severities }
      format.json   { render :json => @alert_severities }
    end
  end
  
  def top_attacks
    @top_attacks = Event.get_top_attacks params
    # Make sure that we pass the actual time to the events page instead of minutes ago. Passing minutes
    # would be a moving target when what we should really want from this is a point in time snapshot.
    unless params[:minutes_ago].blank?
      params.merge!({:start_date => params[:minutes_ago].to_i.minutes.ago.strftime("%Y-%m-%d %H:%M"), :minutes_ago => ''})
    end
    respond_to do |format|
      format.html   { render :layout => false }
      format.iphone { render }
      format.xml    { render :xml => @top_attacks }
      format.json   { render :json => @top_attacks }
    end
  end
  
  def top_attackers
    @top_attackers = Event.get_top_attackers params
    # Make sure that we pass the actual time to the events page instead of minutes ago. Passing minutes
    # would be a moving target when what we should really want from this is a point in time snapshot.
    unless params[:minutes_ago].blank?
      params.merge!({:start_date => params[:minutes_ago].to_i.minutes.ago.strftime("%Y-%m-%d %H:%M"), :minutes_ago => ''})
    end
    respond_to do |format|
      format.html   { render :layout => false }
      format.iphone { render }
      format.xml    { render :xml => @top_attackers.to_xml(:methods => [ :formatted_source_address ]) }
      format.json   { render :json => @top_attackers.to_json(:methods => [ :formatted_source_address ]) }
    end
  end
  
  def high_priority_attacks
    @high_priority_attacks = Event.get_top_high_priority_attacks params
    # Make sure that we pass the actual time to the events page instead of minutes ago. Passing minutes
    # would be a moving target when what we should really want from this is a point in time snapshot.
    unless params[:minutes_ago].blank?
      params.merge!({:start_date => params[:minutes_ago].to_i.minutes.ago.strftime("%Y-%m-%d %H:%M"), :minutes_ago => ''})
    end
    respond_to do |format|
      format.html   { render :layout => false }
      format.iphone { render }
      format.xml    { render :xml => @high_priority_attacks }
      format.json   { render :json => @high_priority_attacks }
    end
  end
  
  def alerts_graph
    @alert_severities = Event.get_alert_severities params
    values = Array.new
    for severity in @alert_severities
      values << PieValue.new(severity.total.to_i, "#{severity.sig_priority} - #{severity.total}")
    end
    
    pie = Pie.new
    pie.values = values
    pie.tooltip = '#val# of #total#<br>#percent# of 100%'
    chart = OpenFlashChart.new
    chart.add_element(pie)
    chart.x_axis = nil
    pie.animate = false
    pie.colours = ["#d01f3c", "#FFFF00", "#33FF00"]
    render :text => chart.to_s
  end
  
  def map
    @countries_array = Event.get_high_priority_attacks_by_country params
    @max_count = @countries_array[0][1][:count].to_f unless @countries_array.empty?
    
    respond_to do |format|
      format.html   { render :layout => false }
      #format.iphone { render }
      #format.xml    { render :xml => @high_priority_attacks }
      #format.json   { render :json => @high_priority_attacks }
    end
  end
end
